@@ -45,7 +45,7 @@ class V(object):
     def __repr__(self):
         return '(%s)-[%s]->(%s)' % (
             '*' if self.src is None else self.src,
-            '*' if self.rel is None else ':%s' % (self.rel),
+            '*' if self.rel is None else ':%s' % self.rel,
             '*' if self.dst is None else self.dst,
         )
 
@@ -56,6 +56,8 @@ class V(object):
 
         :param other: The other thing.
         """
+        if not isinstance(other, V):
+            return NotImplemented
         return (self.src == other.src and
                 self.rel == other.rel and
                 self.dst == other.dst)
@@ -63,8 +65,8 @@ class V(object):
     def __hash__(self):
         """
         Uses Python's tuple hashing algorithm to
-        hash the internal source, relation, and
-        destination nodes.
+        hash the ``id`` integer, internal source,
+        relation, and destination nodes.
         """
         return hash((self.src, self.rel, self.dst))
 
@@ -100,10 +102,10 @@ class Query(object):
         """
         with closing(self.db.cursor()) as cursor:
             cursor.execute(self.statement, self.params)
-            for item in cursor:
-                yield item[0]
+            for row in cursor:
+                yield row[0]
 
-    def derived(self, statement, params=tuple()):
+    def derived(self, statement, params=()):
         """
         Returns a new query object set up correctly with
         the *statement* and *params* appended to the end
@@ -171,7 +173,8 @@ class Query(object):
         Compute the difference between the current
         selected nodes and the another query, and
         explicitly not a `symmetric difference`.
-        Similar to the :meth:``Query.intersection``
+        Similar in concept to
+        :meth:`graphlite.query.Query.intersection`.
         """
         return self.derived(SQL.difference)
 
@@ -180,7 +183,8 @@ class Query(object):
         """
         Compute the union between the current selected
         nodes and another query. Similar to the
-        :meth:``Query.intersection``.
+        :meth:`graphlite.query.Query.intersection`
+        method.
         """
         return self.derived(SQL.union)
 
